@@ -1,35 +1,10 @@
-# some technical stuff
-import sys
-from ._utils import pkg_version, check_versions, annotate_doc_types
+"""Single-Cell Analysis in Python."""
 
-__author__ = ', '.join([
-    'Alex Wolf',
-    'Philipp Angerer',
-    'Fidel Ramirez',
-    'Isaac Virshup',
-    'Sergei Rybakov',
-    'Gokcen Eraslan',
-    'Tom White',
-    'Malte Luecken',
-    'Davide Cittaro',
-    'Tobias Callies',
-    'Marius Lange',
-    'Andrés R. Muñoz-Rojas',
-])
-__email__ = ', '.join([
-    'f.alex.wolf@gmx.de',
-    'philipp.angerer@helmholtz-muenchen.de',
-    # We don’t need all, the main authors are sufficient.
-])
-try:
-    from setuptools_scm import get_version
-    __version__ = get_version(root='..', relative_to=__file__)
-    del get_version
-except (LookupError, ImportError):
-    __version__ = str(pkg_version(__name__))
+from ._metadata import __version__, __author__, __email__
 
+from ._utils import check_versions
 check_versions()
-del pkg_version, check_versions
+del check_versions
 
 # the actual API
 from ._settings import settings, Verbosity  # start with settings as several tools are using it
@@ -46,6 +21,8 @@ from .neighbors import Neighbors
 set_figure_params = settings.set_figure_params
 
 # has to be done at the end, after everything has been imported
+import sys
 sys.modules.update({f'{__name__}.{m}': globals()[m] for m in ['tl', 'pp', 'pl']})
+from ._utils import annotate_doc_types
 annotate_doc_types(sys.modules[__name__], 'scanpy')
 del sys, annotate_doc_types
