@@ -10,6 +10,7 @@ from anndata import AnnData
 from matplotlib.axes import Axes
 from matplotlib import pyplot as pl
 from matplotlib import gridspec
+from warnings import warn
 
 from .. import logging as logg
 from .._compat import Literal
@@ -27,7 +28,7 @@ colorbar_title
 cmap
     String denoting matplotlib color map.
 standard_scale
-    Whether or not to standardize the given dimension between 0 and 1, meaning for 
+    Whether or not to standardize the given dimension between 0 and 1, meaning for
     each variable or group, subtract the minimum and divide each by its maximum.
 swap_axes
      By default, the x axis contains `var_names` (e.g. genes) and the y axis
@@ -66,6 +67,8 @@ class BasePlot(object):
     DEFAULT_LEGENDS_WIDTH = 1.5
     DEFAULT_COLOR_LEGEND_TITLE = 'Expression\nlevel in group'
 
+    MAX_NUM_CATEGORIES = 500  # maximum number of categories allowed to be plotted
+
     def __init__(
         self,
         adata: AnnData,
@@ -91,9 +94,6 @@ class BasePlot(object):
         self.var_group_rotation = var_group_rotation
         self.width, self.height = figsize if figsize is not None else (None, None)
 
-        if use_raw is None and adata.raw is not None:
-            use_raw = True
-
         self.has_var_groups = (
             True
             if var_group_positions is not None and len(var_group_positions) > 0
@@ -112,6 +112,11 @@ class BasePlot(object):
             layer=layer,
             gene_symbols=gene_symbols,
         )
+        if len(self.categories) > self.MAX_NUM_CATEGORIES:
+            warn(
+                f"Over {self.MAX_NUM_CATEGORIES} categories found. "
+                "Plot would be very large."
+            )
 
         if categories_order is not None:
             if set(self.obs_tidy.index.categories) != set(categories_order):
@@ -515,7 +520,7 @@ class BasePlot(object):
             legend_height,
         ]
         fig, legend_gs = make_grid_spec(
-            legend_ax, nrows=2, ncols=1, height_ratios=height_ratios,
+            legend_ax, nrows=2, ncols=1, height_ratios=height_ratios
         )
 
         color_legend_ax = fig.add_subplot(legend_gs[1])
@@ -792,9 +797,7 @@ class BasePlot(object):
         self.make_figure()
         pl.savefig(filename, bbox_inches=bbox_inches, **kwargs)
 
-    def _reorder_categories_after_dendrogram(
-        self, dendrogram,
-    ):
+    def _reorder_categories_after_dendrogram(self, dendrogram):
         """\
         Function used by plotting functions that need to reorder the the groupby
         observations based on the dendrogram results.
