@@ -12,6 +12,7 @@ from .. import _utils
 from .. import logging as logg
 from ..preprocessing._simple import _get_mean_var
 from .._compat import Literal
+from ..get import _get_obs_rep
 
 
 _Method = Optional[Literal['logreg', 't-test', 'wilcoxon', 't-test_overestim_var']]
@@ -97,6 +98,17 @@ class _RankGenes:
             adata, groups, groupby
         )
 
+        # Singlet groups cause division by zero errors
+        invalid_groups_selected = set(self.groups_order) & set(
+            adata.obs[groupby].value_counts().loc[lambda x: x < 2].index
+        )
+
+        if len(invalid_groups_selected) > 0:
+            raise ValueError(
+                "Could not calculate statistics for groups {} since they only "
+                "contain one sample.".format(', '.join(invalid_groups_selected))
+            )
+
         adata_comp = adata
         if layer is not None:
             if use_raw:
@@ -433,6 +445,8 @@ def rank_genes_groups(
     """\
     Rank genes for characterizing groups.
 
+    Expects logarithmized data.
+
     Parameters
     ----------
     adata
@@ -515,8 +529,7 @@ def rank_genes_groups(
     >>> import scanpy as sc
     >>> adata = sc.datasets.pbmc68k_reduced()
     >>> sc.tl.rank_genes_groups(adata, 'bulk_labels', method='wilcoxon')
-
-    # to visualize the results
+    >>> # to visualize the results
     >>> sc.pl.rank_genes_groups(adata)
     """
     if method is None:
@@ -628,15 +641,22 @@ def rank_genes_groups(
     return adata if copy else None
 
 
+def _calc_frac(X):
+    if issparse(X):
+        n_nonzero = X.getnnz(axis=0)
+    else:
+        n_nonzero = np.count_nonzero(X, axis=0)
+    return n_nonzero / X.shape[0]
+
+
 def filter_rank_genes_groups(
     adata: AnnData,
     key=None,
     groupby=None,
-    use_raw=True,
-    log=True,
+    use_raw=None,
     key_added='rank_genes_groups_filtered',
     min_in_group_fraction=0.25,
-    min_fold_change=2,
+    min_fold_change=1,
     max_out_group_fraction=0.5,
 ) -> None:
     """\
@@ -657,8 +677,6 @@ def filter_rank_genes_groups(
     key
     groupby
     use_raw
-    log
-        If true, it means that the values to work with are in log scale
     key_added
     min_in_group_fraction
     min_fold_change
@@ -684,7 +702,19 @@ def filter_rank_genes_groups(
         key = 'rank_genes_groups'
 
     if groupby is None:
-        groupby = str(adata.uns[key]['params']['groupby'])
+        groupby = adata.uns[key]['params']['groupby']
+
+    if use_raw is None:
+        use_raw = adata.uns[key]['params']['use_raw']
+
+    same_params = (
+        adata.uns[key]['params']['groupby'] == groupby
+        and adata.uns[key]['params']['reference'] == 'rest'
+        and adata.uns[key]['params']['use_raw'] == use_raw
+    )
+
+    use_logfolds = same_params and 'logfoldchanges' in adata.uns[key]
+    use_fraction = same_params and 'pts_rest' in adata.uns[key]
 
     # convert structured numpy array into DataFrame
     gene_names = pd.DataFrame(adata.uns[key]['names'])
@@ -694,76 +724,69 @@ def filter_rank_genes_groups(
         columns=gene_names.columns,
         index=gene_names.index,
     )
-    fold_change_matrix = pd.DataFrame(
-        np.zeros(gene_names.shape),
-        columns=gene_names.columns,
-        index=gene_names.index,
-    )
     fraction_out_cluster_matrix = pd.DataFrame(
         np.zeros(gene_names.shape),
         columns=gene_names.columns,
         index=gene_names.index,
     )
+
+    if use_logfolds:
+        fold_change_matrix = pd.DataFrame(adata.uns[key]['logfoldchanges'])
+    else:
+        fold_change_matrix = pd.DataFrame(
+            np.zeros(gene_names.shape),
+            columns=gene_names.columns,
+            index=gene_names.index,
+        )
+
+        if 'log1p' in adata.uns_keys() and adata.uns['log1p']['base'] is not None:
+            expm1_func = lambda x: np.expm1(x * np.log(adata.uns['log1p']['base']))
+        else:
+            expm1_func = np.expm1
+
     logg.info(
         f"Filtering genes using: "
         f"min_in_group_fraction: {min_in_group_fraction} "
         f"min_fold_change: {min_fold_change}, "
         f"max_out_group_fraction: {max_out_group_fraction}"
     )
-    from ..plotting._anndata import _prepare_dataframe
+
     for cluster in gene_names.columns:
         # iterate per column
         var_names = gene_names[cluster].values
 
-        # add column to adata as __is_in_cluster__. This facilitates to measure
-        # fold change of each gene with respect to all other clusters
-        adata.obs['__is_in_cluster__'] = pd.Categorical(adata.obs[groupby] == cluster)
+        if not use_logfolds or not use_fraction:
+            sub_X = adata.raw[:, var_names].X if use_raw else adata[:, var_names].X
+            in_group = adata.obs[groupby] == cluster
+            X_in = sub_X[in_group]
+            X_out = sub_X[~in_group]
 
-        # obs_tidy has rows=groupby, columns=var_names
-        categories, obs_tidy = _prepare_dataframe(
-            adata,
-            var_names,
-            groupby='__is_in_cluster__',
-            use_raw=use_raw,
-        )
-
-        # for if category defined by groupby (if any) compute for each var_name
-        # 1. the mean value over the category
-        # 2. the fraction of cells in the category having a value > 0
-
-        # 1. compute mean value
-        mean_obs = obs_tidy.groupby(level=0).mean()
-
-        # 2. compute fraction of cells having value >0
-        # transform obs_tidy into boolean matrix
-        obs_bool = obs_tidy.astype(bool)
-
-        # compute the sum per group which in the boolean matrix this is the number
-        # of values >0, and divide the result by the total number of values in the group
-        # (given by `count()`)
-        fraction_obs = obs_bool.groupby(level=0).sum() / obs_bool.groupby(level=0).count()
-
-        # Because the dataframe groupby is based on the '__is_in_cluster__' column,
-        # in this context, [True] means __is_in_cluster__.
-        # Also, in this context, fraction_obs.loc[True].values is the row of values
-        # that is assigned *as column* to fraction_in_cluster_matrix to follow the
-        # structure of the gene_names dataFrame
-        fraction_in_cluster_matrix.loc[:, cluster] = fraction_obs.loc[True].values
-        fraction_out_cluster_matrix.loc[:, cluster] = fraction_obs.loc[False].values
-
-        # compute fold change.
-        if log:
-            fold_change_matrix.loc[:, cluster] = (np.exp(mean_obs.loc[True]) / np.exp(mean_obs.loc[False])).values
+        if use_fraction:
+            fraction_in_cluster_matrix.loc[:, cluster] = (
+                adata.uns[key]['pts'][cluster].loc[var_names].values
+            )
+            fraction_out_cluster_matrix.loc[:, cluster] = (
+                adata.uns[key]['pts_rest'][cluster].loc[var_names].values
+            )
         else:
-            fold_change_matrix.loc[:, cluster] = (mean_obs.loc[True] / mean_obs.loc[False]).values
+            fraction_in_cluster_matrix.loc[:, cluster] = _calc_frac(X_in)
+            fraction_out_cluster_matrix.loc[:, cluster] = _calc_frac(X_out)
+
+        if not use_logfolds:
+            # compute mean value
+            mean_in_cluster = np.ravel(X_in.mean(0))
+            mean_out_cluster = np.ravel(X_out.mean(0))
+            # compute fold change
+            fold_change_matrix.loc[:, cluster] = np.log2(
+                (expm1_func(mean_in_cluster) + 1e-9)
+                / (expm1_func(mean_out_cluster) + 1e-9)
+            )
 
-    # remove temporary columns
-    adata.obs.drop(columns='__is_in_cluster__')
     # filter original_matrix
     gene_names = gene_names[
-        (fraction_in_cluster_matrix > min_in_group_fraction) &
-        (fraction_out_cluster_matrix < max_out_group_fraction) &
-        (fold_change_matrix > min_fold_change)
+        (fraction_in_cluster_matrix > min_in_group_fraction)
+        & (fraction_out_cluster_matrix < max_out_group_fraction)
+        & (fold_change_matrix > min_fold_change)
     ]
     # create new structured array using 'key_added'.
     adata.uns[key_added] = adata.uns[key].copy()
